#!/usr/bin/env python3

import getpass
import os
import subprocess

from .adfs_auth import authenticate
from .assume_role import ask_which_role_to_assume, assume_role
from .roles import action_url_on_validation_success, retrieve_roles_page

def cli():
    # Get the federated credentials from the user
    net_id = input('BYU Net ID: ')
    username = '{}@byu.local'.format(net_id)
    password = getpass.getpass()
    print('')
    
    ####
    # Authenticate against ADFS with DUO MFA
    ####
    html_response, session, auth_signature, duo_request_signature = authenticate(username, password)
    
    ####
    # Obtain the roles available to assume
    ####
    roles_page_url = action_url_on_validation_success(html_response)
    account_names, principal_roles, assertion, aws_session_duration = retrieve_roles_page(
        roles_page_url,
        html_response,
        session,
        auth_signature,
        duo_request_signature,
    )
    
    ####
    # Ask user which role to assume
    ####
    print(principal_roles)
    chosen_principal_role = ask_which_role_to_assume(account_names, principal_roles)
    
    ####
    # Assume role and set in the environment
    ####
    aws_session_token = assume_role(chosen_principal_role[1], chosen_principal_role[0], assertion)
        
    subprocess.check_call('aws configure set aws_access_key_id {}'.format(aws_session_token['Credentials']['AccessKeyId']), shell=True)
    subprocess.check_call('aws configure set aws_secret_access_key {}'.format(aws_session_token['Credentials']['SecretAccessKey']), shell=True)
    subprocess.check_call('aws configure set aws_session_token {}'.format(aws_session_token['Credentials']['SessionToken']), shell=True)
    subprocess.check_call('aws configure set region us-west-2', shell=True)
    
    #proc = subprocess.Popen(args, env=os.environ)
    
    # Overwrite and delete the credential variables, just for safety
    username = '##############################################'
    password = '##############################################'
    del username
    del password
    
if __name__ == '__main__':
    cli()


import boto3
import botocore
from botocore import client

def _get_roles_by_account(account_names, principal_roles):
    index = 0
    roles_by_account = {}
    for (principal_arn, role_arn) in principal_roles:
        account_id = role_arn.split(':')[4]
        account_name = account_names[account_id]
        account_role = role_arn.split(':')[5].split('/')[1]

        if not roles_by_account.get(account_name):
            roles_by_account[account_name] = {}

        roles_by_account[account_name][account_role] = {}
        roles_by_account[account_name][account_role]['index'] = index
        index += 1
    return roles_by_account


def ask_which_role_to_assume(account_names, principal_roles):
    print("#--------------------------------------------------")
    print("# Which role would you like to assume? ")
    print("#--------------------------------------------------")

    roles_by_account = _get_roles_by_account(account_names, principal_roles)

    for account_name in roles_by_account:
        print('{}:'.format(account_name))
        for account_role in roles_by_account[account_name]:
            index = roles_by_account[account_name][account_role]['index']
            print('  {} - {}'.format(account_role, index))
        print()

    role_index = int(input("Select role: "))
    return principal_roles[role_index]


def assume_role(roleArn, principalArn, samlAssertion):
    conn = boto3.client('sts', config=client.Config(signature_version=botocore.UNSIGNED))
    aws_session_token = conn.assume_role_with_saml(
        RoleArn=roleArn,
        PrincipalArn=principalArn,
        SAMLAssertion=samlAssertion,
        DurationSeconds=3600,
    )
    
    return aws_session_token





#!/usr/bin/env python3

import sys
from setuptools import setup, find_packages

if int(sys.version[0]) < 3:
    sys.stderr.write("byu_awslogin requires python 3\n")
    sys.exit(-1)

# we only use the subset of markdown that is also valid reStructuredText so
# that our README.md works on both github (markdown) and pypi (reStructuredText)
with open("README.md") as rm_file:
    long_description = rm_file.read()

def get_requirements():
    with open('requirements.txt') as obj:
        lines = [dep for dep in obj.read().split('\n') if dep]
        return lines

setup(name='byu_awslogin',
      version='0.9.1',
      description="An aws-adfs spinoff that fits BYU's needs",
      long_description=long_description,
      author='BYU OIT Application Development',
      author_email='it@byu.edu',
      url='https://github.com/byu-oit/awslogin',
      packages=find_packages(),
      data_files=[('', ['README.md', 'LICENSE'])],
      license="Apache 2",
      install_requires=get_requirements(),
      zip_safe=True,
      entry_points={
          'console_scripts': ['awslogin=byu_awslogin.index:cli']
      }
      )